@@ -50,7 +50,12 @@ def isSlience(Filename =None):
     suffix = os.path.splitext(Filename)[-1]
     if suffix == '.mp4':
         Filename = get_wav_from_mp4(Filename)
-    ins,_ = get_data_array(Filename)
+    if suffix == '.pcm':
+        pcmf = open(Filename, 'rb')
+        ins = pcmf.read()
+        pcmf.close()
+    if suffix == '.wav':
+        ins,_ = get_data_array(Filename)
     dBrmsValue = 20*math.log10(get_rms(ins)/32767+ 1.0E-6)
     print(dBrmsValue)
     if dBrmsValue > -70:
@@ -85,6 +90,6 @@ def audioFormat(wavFileName=None):
     return refChannel,refsamWidth*8,refsamplerate,refframeCount
 
 if __name__ == '__main__':
-    ref = r'C:\Users\vcloud_avl\Documents\我的POPO\1meiy.wav'
+    ref = r'C:\Users\vcloud_avl\Documents\我的POPO\src.pcm'
     print(isSlience(ref))
-    print(audioFormat(ref))
\ No newline at end of file
+    #print(audioFormat(ref))
\ No newline at end of file
