@@ -21,11 +21,11 @@ def cal_snr_transient(refFile=None, noisetFile=None, testFile=None):
         raise TypeError('Different format of ref and test files!')
     mydll = ctypes.windll.LoadLibrary(sys.prefix + '/snr_transient.dll')
     mydll.SNR_transient.argtypes = [POINTER(emxArray_real_T),POINTER(emxArray_real_T),POINTER(emxArray_real_T),c_double, POINTER(c_double),POINTER(c_double),POINTER(c_double)]
-    snr,noise,err = c_double(0.0),c_double(0.0),c_double(0.0)
-    mydll.SNR_transient(byref(refstruct),byref(noiseStruct),byref(teststruct),c_double(refsamplerate),byref(snr),byref(noise),byref(err))
+    snr_1,snr_2,err = c_double(0.0),c_double(0.0),c_double(0.0)
+    mydll.SNR_transient(byref(refstruct),byref(noiseStruct),byref(teststruct),c_double(refsamplerate),byref(snr_1),byref(snr_2),byref(err))
 
     if err.value == 0.0:
-        return snr.value
+        return snr_1.value,snr_2.value
     else:
         return None
 
