@@ -26,8 +26,11 @@ from AGC_EVALUATION.CAL_GAIN_TABLE import cal_gain_table
 from AGC_EVALUATION.CAL_ATTACK_RELEASE import cal_attack_release
 from AGC_EVALUATION.CAL_MUSIC_STABILITY import cal_music_stablility
 from AGC_EVALUATION.CAL_DELAY import cal_DELAY
+from AEC_EVALUATION.MATCH_AEC import MATCH_AEC
+from AEC_EVALUATION.ERLE_ETSIMATION import cal_erle
+from FUNCTION.audioFunction import isSlience,audioFormat
 
-allMetrics = ['G160','P563','POLQA','PESQ','STOI','STI','PEAQ','SDR','SII','LOUDNESS','MUSIC','TRANSIENT','MATCH','GAINTABLE','ATTACKRELEASE','MUSICSTA','AGCDELAY']
+allMetrics = ['G160','P563','POLQA','PESQ','STOI','STI','PEAQ','SDR','SII','LOUDNESS','MUSIC','TRANSIENT','MATCH','GAINTABLE','ATTACKRELEASE','MUSICSTA','AGCDELAY','SLIENCE','FORMAT']
 
 
 class computeAudioQuality():
@@ -307,4 +310,21 @@ class computeAudioQuality():
         """
         self.__double_end_check()
         return cal_DELAY(refFile=pcm2wav(self.refFile, sample_rate=self.samplerate),
-                             testFile=pcm2wav(self.testFile, sample_rate=self.samplerate))
\ No newline at end of file
+                             testFile=pcm2wav(self.testFile, sample_rate=self.samplerate))
+
+
+    def SLIENCE(self):
+        """
+        Returns
+        -------
+
+        """
+        return isSlience(self.testFile)
+
+    def FORMAT(self):
+        """
+        Returns
+        -------
+
+        """
+        return audioFormat(self.testFile)
\ No newline at end of file
